==> stage_2.0.3.orig.tar.gz: stage-2.0.3.orig/src/gui.h <==

// GUI constants

#define STG_LAYER_BACKGROUND 10
#define STG_LAYER_BODY 30
#define STG_LAYER_GRID 20
#define STG_LAYER_USER 99
#define STG_LAYER_GEOM 80
#define STG_LAYER_MATRIX 40
#define STG_LAYER_MATRIX_TREE 39
#define STG_LAYER_DEBUG 98

#define STG_LAYER_BLOBGEOM 51
#define STG_LAYER_BLOBCONFIG 52
#define STG_LAYER_BLOBDATA 53

#define STG_LAYER_PTZGEOM 54
#define STG_LAYER_PTZONFIG 56
#define STG_LAYER_PTZDATA 57

#define STG_LAYER_NEIGHBORGEOM 61
#define STG_LAYER_NEIGHBORCONFIG 62
#define STG_LAYER_NEIGHBORDATA 63

#define STG_LAYER_ENERGYGEOM 71
#define STG_LAYER_ENERGYCONFIG 72
#define STG_LAYER_ENERGYDATA 73

#define STG_GRID_MAJOR_COLOR "gray85"
#define STG_GRID_MINOR_COLOR "gray95"
#define STG_GRID_AXIS_COLOR "gray40"
#define STG_BACKGROUND_COLOR "ivory"
#define STG_BOUNDINGBOX_COLOR "magenta"
#define STG_MATRIX_COLOR "dark green"

  // model color defaults
#define STG_FIDUCIAL_COLOR "lime green"
#define STG_FIDUCIAL_CFG_COLOR "green"

#define STG_ENERGY_COLOR "purple"
#define STG_ENERGY_CFG_COLOR "magenta"
   
#define STG_DEBUG_COLOR "red"
#define STG_BLOB_CFG_COLOR "gray75"

#define STG_LAYER_RANGERGEOM 41
#define STG_LAYER_RANGERCONFIG 42
#define STG_LAYER_RANGERDATA 43

#define STG_LAYER_BUMPERGEOM 60
#define STG_LAYER_BUMPERCONFIG 61
#define STG_LAYER_BUMPERDATA 62

#define STG_RANGER_COLOR "gray75" 
#define STG_RANGER_GEOM_COLOR "orange"
#define STG_RANGER_CONFIG_COLOR "gray90"

#define STG_LAYER_LASERGEOM 32
#define STG_LAYER_LASERDATA 31
#define STG_LAYER_LASERCONFIG 32

#define STG_LAYER_POSITIONGEOM 45
#define STG_LAYER_POSITIONDATA 47
#define STG_LAYER_POSITIONCONFIG 46

#define STG_LASER_COLOR "steel blue"
#define STG_LASER_FILL_COLOR "powder blue"
#define STG_LASER_GEOM_COLOR "blue"
#define STG_LASER_CFG_COLOR "light steel blue"
#define STG_LASER_BRIGHT_COLOR "blue"

#define STG_LAYER_GRIPPERGEOM 85
#define STG_LAYER_GRIPPERDATA 87
#define STG_LAYER_GRIPPERCONFIG 86

#define STG_GRIPPER_COLOR "steel blue"
#define STG_GRIPPER_FILL_COLOR "light blue"
#define STG_GRIPPER_GEOM_COLOR "blue"
#define STG_GRIPPER_CFG_COLOR "light steel blue"
#define STG_GRIPPER_BRIGHT_COLOR "blue"

  // GUI colors   
#define STG_GRID_MAJOR_COLOR "gray85"
#define STG_GRID_MINOR_COLOR "gray95"
#define STG_MATRIX_COLOR "dark green"
#define STG_BACKGROUND_COLOR "ivory"
  
  // model color defaults
#define STG_GENERIC_COLOR "black"
#define STG_POSITION_COLOR "red"
#define STG_WALL_COLOR "dark blue"
#define STG_SONAR_COLOR "gray70"

#define STG_LAYER_SPEECHDATA 88
#define STG_SPEECH_COLOR "navy"

==> stage_2.1.1.orig.tar.gz: stage-2.1.1/src/gui.h <==

// GUI constants

#define STG_LAYER_BACKGROUND 10
#define STG_LAYER_BODY 30
#define STG_LAYER_GRID 20
#define STG_LAYER_USER 99
#define STG_LAYER_GEOM 80
#define STG_LAYER_MATRIX 40
#define STG_LAYER_MATRIX_TREE 39
#define STG_LAYER_DEBUG 98

#define STG_LAYER_BLOBGEOM 51
#define STG_LAYER_BLOBCONFIG 52
#define STG_LAYER_BLOBDATA 53

#define STG_LAYER_PTZGEOM 54
#define STG_LAYER_PTZONFIG 56
#define STG_LAYER_PTZDATA 57

#define STG_LAYER_NEIGHBORGEOM 61
#define STG_LAYER_NEIGHBORCONFIG 62
#define STG_LAYER_NEIGHBORDATA 63

#define STG_LAYER_ENERGYGEOM 71
#define STG_LAYER_ENERGYCONFIG 72
#define STG_LAYER_ENERGYDATA 73

#define STG_GRID_MAJOR_COLOR "gray85"
#define STG_GRID_MINOR_COLOR "gray95"
#define STG_GRID_AXIS_COLOR "gray40"
#define STG_BACKGROUND_COLOR "ivory"
#define STG_BOUNDINGBOX_COLOR "magenta"
#define STG_MATRIX_COLOR "dark green"

  // model color defaults
#define STG_FIDUCIAL_COLOR "lime green"
#define STG_FIDUCIAL_CFG_COLOR "green"

#define STG_ENERGY_COLOR "purple"
#define STG_ENERGY_CFG_COLOR "magenta"
   
#define STG_DEBUG_COLOR "red"
#define STG_BLOB_CFG_COLOR "gray75"

#define STG_LAYER_RANGERGEOM 41
#define STG_LAYER_RANGERCONFIG 42
#define STG_LAYER_RANGERDATA 43

#define STG_LAYER_BUMPERGEOM 60
#define STG_LAYER_BUMPERCONFIG 61
#define STG_LAYER_BUMPERDATA 62

#define STG_LAYER_WIFICONFIG 64
#define STG_LAYER_WIFIDATA 65

#define STG_RANGER_COLOR "gray75" 
#define STG_RANGER_GEOM_COLOR "orange"
#define STG_RANGER_CONFIG_COLOR "gray90"

#define STG_LAYER_LASERGEOM 32
#define STG_LAYER_LASERDATA 31
#define STG_LAYER_LASERCONFIG 32

#define STG_LAYER_POSITIONGEOM 45
#define STG_LAYER_POSITIONDATA 47
#define STG_LAYER_POSITIONCONFIG 46

#define STG_LASER_COLOR "steel blue"
#define STG_LASER_FILL_COLOR "powder blue"
#define STG_LASER_GEOM_COLOR "blue"
#define STG_LASER_CFG_COLOR "light steel blue"
#define STG_LASER_BRIGHT_COLOR "blue"

#define STG_WIFI_CFG_COLOR "royal blue"
#define STG_WIFI_CFG_COLOR_GREEN "DarkGreen"


#define STG_LAYER_GRIPPERGEOM 85
#define STG_LAYER_GRIPPERDATA 87
#define STG_LAYER_GRIPPERCONFIG 86

#define STG_GRIPPER_COLOR "steel blue"
#define STG_GRIPPER_FILL_COLOR "light blue"
#define STG_GRIPPER_GEOM_COLOR "blue"
#define STG_GRIPPER_CFG_COLOR "light steel blue"
#define STG_GRIPPER_BRIGHT_COLOR "blue"

  // GUI colors   
#define STG_GRID_MAJOR_COLOR "gray85"
#define STG_GRID_MINOR_COLOR "gray95"
#define STG_MATRIX_COLOR "dark green"
#define STG_BACKGROUND_COLOR "ivory"
  
  // model color defaults
#define STG_GENERIC_COLOR "black"
#define STG_POSITION_COLOR "red"
#define STG_WALL_COLOR "dark blue"
#define STG_SONAR_COLOR "gray70"

#define STG_LAYER_SPEECHDATA 88
#define STG_SPEECH_COLOR "navy"

#define STG_LAYER_AUDIODATA 84
#define STG_AUDIO_COLOR "orange3"
#define STG_AUDIO_BUBBLE_COLOR "orange4"
